[PATCH] sound/soc/soc-core: Removed instances of 'blacklist'

Paul Schulz paul at mawsonlakes.org
Wed Jul 15 18:48:36 CEST 2020


This patch removes 'blacklist' and replaces it with
'invalid list' in sound/soc/soc-core.c

This is a functionally trivial patch and has no other effect.

Signed-off-by: Paul Schulz <paul at mawsonlakes.org>
---
 sound/soc/soc-core.c | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/sound/soc/soc-core.c b/sound/soc/soc-core.c
index 0f30f5aabaa8..6bc56c4cb207 100644
--- a/sound/soc/soc-core.c
+++ b/sound/soc/soc-core.c
@@ -1457,11 +1457,11 @@ EXPORT_SYMBOL_GPL(snd_soc_runtime_set_dai_fmt);
 
 #ifdef CONFIG_DMI
 /*
  * If a DMI filed contain strings in this blacklist (e.g.
  * "Type2 - Board Manufacturer" or "Type1 - TBD by OEM"), it will be taken
  * as invalid and dropped when setting the card long name from DMI info.
  */
-static const char * const dmi_blacklist[] = {
+static const char * const dmi_invalid_list[] = {
 	"To be filled by OEM",
 	"TBD by OEM",
 	"Default String",
@@ -1493,14 +1493,14 @@ static void cleanup_dmi_name(char *name)
 
 /*
  * Check if a DMI field is valid, i.e. not containing any string
  * in the black list.
  */
 static int is_dmi_valid(const char *field)
 {
 	int i = 0;
 
-	while (dmi_blacklist[i]) {
-		if (strstr(field, dmi_blacklist[i]))
+	while (dmi_invalid_list[i]) {
+		if (strstr(field, dmi_invalid_list[i]))
 			return 0;
 		i++;
 	}
@@ -1457,11 +1457,11 @@ EXPORT_SYMBOL_GPL(snd_soc_runtime_set_dai_fmt);
 #ifdef CONFIG_DMI
 /*
- * If a DMI filed contain strings in this blacklist (e.g.
+ * If a DMI filed contain strings in this invalid list (e.g.
  * "Type2 - Board Manufacturer" or "Type1 - TBD by OEM"), it will be taken
  * as invalid and dropped when setting the card long name from DMI info.
@@ -1493,14 +1493,14 @@ static void cleanup_dmi_name(char *name)
 /*
  * Check if a DMI field is valid, i.e. not containing any string
- * in the black list.
+ * in the invalid list.
  */
 static int is_dmi_valid(const char *field)
-- 
2.25.1



More information about the Alsa-devel mailing list